#
# spec file for package filezilla
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           filezilla
Version:        3.12.0.2
Release:        1.1
Summary:        A GUI FTP and SFTP Client
License:        GPL-2.0+
Group:          Productivity/Networking/Ftp/Clients
Url:            http://filezilla-project.org/
Source0:        http://prdownloads.sourceforge.net/filezilla/FileZilla_%{version}_src.tar.bz2
Patch0:         putty-no_DATE_and_TIME_.patch
Patch1:         filezilla-3.5.3-buildinfo-no-date.patch
BuildRequires:  cppunit-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  tinyxml-devel
BuildRequires:  update-desktop-files
%if 0%{suse_version} >= 1310
BuildRequires:  wxWidgets-3_0-devel >= 3.0.2
%else
BuildRequires:  wxWidgets-devel >= 3.0.2
%endif
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gnutls) >= 3.1.12
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(sqlite3)
Requires(pre):  update-desktop-files
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FileZilla is a modern and powerful FTP client for Windows and Linux.
FileZilla development focuses on high usability while also supporting
as many useful features as possible. FileZilla is "Open Source" under
the GPL license.

Some of the main features are:
   * Continuing interrupted up-/downloads
   * Managing different FTP sites
   * Modifiable Commands
   * Keep-Alive-System
   * Timeout detection
   * Firewall support
   * SOCKS4/5 and HTTP 1.1 proxy support
   * SSL support (secure connections)
   * SFTP support
   * Upload/Download queue
   * Drag&Drop support

%lang_package

%prep
%setup -q
%patch0
%patch1

# Fix invalid translation locales:
cd locales
for LOC in\
    bg_BG\
    ca_ES@valencia\
    cs_CZ\
    da_DK\
    fa_IR\
    fi_FI\
    gl_ES\
    he_IL\
    hu_HU\
    id_ID\
    ja_JP\
    km_KH\
    ko_KR\
    lt_LT\
    lv_LV\
    mk_MK\
    nb_NO\
    nn_NO\
    pl_PL\
    pt_PT\
    ro_RO\
    sl_SI\
    sk_SK\
    th_TH\
    uk_UA\
    vi_VN;
do
    mv -iv $LOC.po ${LOC/_??}.po
done

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%configure \
        --disable-static \
	--disable-manualupdatecheck \
	--disable-autoupdatecheck \
	--with-tinyxml=system \
	--with-dbus
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}
%find_lang %{name}

%files
%defattr(-, root, root)
%doc README NEWS COPYING AUTHORS
%{_bindir}/%{name}
%{_bindir}/fzsftp
%{_bindir}/fzputtygen
%{_datadir}/%{name}
%dir %{_datadir}/appdata/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/filezilla.*
%{_mandir}/man1/fzputtygen.*
%{_mandir}/man1/fzsftp.*
%{_mandir}/man5/fzdefaults.xml.*

%files -f %{name}.lang lang
%defattr(-, root, root)

%changelog
* Sat Oct 15 2016 ecsos@opensuse.org
- branch from network-repo and renamed to filezilla-old.
  This is the last version who can build for openSUSE
  13.2, 42.1 and 42.2 without additional repositorys for not
  existing newer needed package versions.
* Sun Jul 19 2015 ecsos@opensuse.org
- version bump to 3.12.0.2:
  * Fix regression on servers that have MLSD facts disabled by
    default
- changes from 3.12.0.1:
  * Fix detection of UTF-8 support
  * Fix location of file list status bar, it was shifted by one
    pixel
* Fri Jul 10 2015 alarrosa@suse.com
- BuildRequire wxWidgets-3_0-devel in openSUSE 13.1, 13.2 and others
  (suse_version >= 1310) instead of wxWidgets-devel
* Fri Jul 10 2015 tchvatal@suse.com
- Version bump to 3.12.0:
  * Various small fixes all around
- Upstreamed patch:
  * filezilla-string-conversion.patch
* Sun Jun  7 2015 tchvatal@suse.com
- Version bump to 3.11.0.2:
  * Fix crasher during some server-client scenarios
  * Work with non-epoch time received from server
- Added patch:
  * filezilla-string-conversion.patch
* Wed May 27 2015 tchvatal@suse.com
- Version bump to 3.11.0.1:
  * Quite few small fixes around
* Tue Mar 31 2015 tchvatal@suse.com
- Version bump to 3.10.3:
  * Various small fixes
  * Merged suse patches
- Removed patches:
  * wxstring-conversions-fix.patch
  * fix-missing-include-fz-bug-10280.patch
* Sun Mar 22 2015 devel.suse@gmail.com
- Filezilla now requires wxWidgets >= 3.0.2
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch to build with our wxwidgets wxstring-conversions-fix.patch
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch fix-missing-include-fz-bug-10280.patch to fix build
* Tue Mar  3 2015 tchvatal@suse.com
- Version bump to 3.10.2:
  * In the XML files, passwords are now base64 encoded
  * The subject area in the certificate verification can now be scrolled if the
    certificate contains many alternative names
  * Many performance improvements
  * Various bugfixes
* Fri Oct  3 2014 tchvatal@suse.com
- Version bump to 3.9.0.5:
  * use wxwidgets-3.0
  * various layout fixes
  * assertion fixes
  * new additional iconset
- Accidentaly fix bnc#898879 by updating
* Thu Aug 14 2014 dimstar@opensuse.org
- Update to version 3.8.1:
  + OS X: Partial support for retina displays.
  + Fixed several small memory leaks.
- Changes from version 3.8.0:
  + Popup dialogs no longer automatically open if other dialogs are
    already open. This prevents FileZilla from becoming
    unresponsive on OS X
  + Fix calculation of current transfer speed. In some situations
    the transfer speed tooltip over the activity indicators showed
    negative speeds.
  + Fix handling of focus item in local directory listings if
    connecting to a site with a default local directory.
* Mon Jan 13 2014 tchvatal@suse.com
- Fix dependencies for the Factory build again and remove few
  useless lines.
* Fri Aug  9 2013 tchvatal@suse.com
- Version bump to 3.7.3
  - Full changelog: https://filezilla-project.org/changelog.php
  - Noteworthy changes:
  * Apply a fix for a security vulnerability in PuTTY as used in FileZilla to handle SFTP. See CVE-2013-4852 for reference.
  * Merge further fixes from PuTTY to address CVE-2013-4206, CVE-2013-4207, CVE-2013-4208
* Mon May 13 2013 tchvatal@suse.com
- Version bump to 3.7.0.1
  - Fix issues with bundled gnutls
  - Update translations
* Fri May 10 2013 tchvatal@suse.com
- Update to version 3.7.0. Changes since 3.6.0.2:
  - Show total transfer speed as tooltip over the transfer indicators
  - List supported protocols in tooltip of host field in quickconnect bar
  - Use TLS instead of the deprecated term SSL
  - Reworded text when saving of passwords is disabled, do not refer to kiosk mode
  - Improved usability of Update page in settings dialog
  - Improve SFTP performance
  - When navigating to the parent directory, highlight the former child
  - When editing files, use high priority for the transfers
  - Add label to size conditions in filter conditions dialog indicating that the unit is bytes
  - Ignore drag&drop operations where source and target are identical and clarify the wording in some drop error cases
  - Trim whitespace from the entered port numbers
  - Slightly darker color of inactive tabs
  - Ignore .. item in the file list context menus if multiple items are selected
  - Display TLS version and key exchange algorithm in certificate and encryption details dialog for FTP over TLS connections.
  - Fix handling of remote paths containing double-quotes
  - Fix crash when opening local directories in Explorer if the name contained characters not representable in the locale's narrow-width character set.
  - Fix a memory leak in the host key verification dialog for SFTP
  - Fix drag-scrolling in file lists with very low height
  - Don't attempt writing XML files upon loading them
  - Improve handling of legacy DDE file associations
  - Fix handling of HTTPS in the auto updater in case a mirror redirects to HTTPS
* Tue Mar  5 2013 nico.kruber@gmail.com
- Update to version 3.6.0.2. Changes since 3.5.3:
  - 3.6.0.2 (2012-11-29)
  * Fix problems with stalling FTP over TLS uploads
  * MSW: Minor performance increase listing local files
  - 3.6.0.1 (2012-11-18)
  * Fix problems with TLS cipher selection, including a bugfix
    for GnuTLS
  * Fix a crash on shutdown
  * Add log message for servers not using UTF-8
  * Small performance and memory optimizations getting file
    types
  * Improve formatting of transfer speeds
  - 3.6.0 (2012-11-10)
  * Fix a crash introduced since 3.5.3
  * IPv6-only hosts should no longer cause a crash in the
    network configuration wizard
* Thu Apr  5 2012 andreas.stieger@gmx.de
- add filezilla-3.5.3-buildinfo-no-date.patch
  fixing W: file-contains-date-and-time
* Tue Jan 10 2012 cstender@suse.com
- Update to version 3.5.3. Changes since 3.5.2:
  + Ctrl+Shift+O can be used to toggle between modification time and filesize based directory comparison
  - It is now possible to use custom passwords if using "anonymous" as user name
  - After un-hiding toolbar, update toolbar button states
  - Fix TLS compatibility issues with TLS 1.2 servers
  - MSW: Unset hidden attribute on FileZilla's settings files
  - Building FileZilla from source now requires wxWidgets 2.8.12 or higher.
* Wed Dec 14 2011 fisiu@opensuse.org
- Update to 3.5.2. Changes since 3.5.1:
    3.5.2 (2011-11-08)
  - Updated translations
    3.5.2-rc1 (2011-11-01)
    + Added option to open site manager on startup to the settings dialog
  - The "Don't save passwords" option was not being saved
  - The queue was not saved correctly if having items from multiple servers
  - Queue items with the lowest priority setting are now being restored again
  - Drag & Drop did not work with all saved sites if saving of passwords had been disabled
* Wed Oct 26 2011 fisiu@opensuse.org
- Update to 3.5.1. Changes since 3.4.0:
    3.5.1 (2011-08-28)
  - Add support for another rate variant of MVS style directory listings
    3.5.1-rc1 (2011-08-21)
    + Add menu item to hide toolbar
  - Don't save server list in kiosk mode 2
  - Fix for predefined sites not appearing in all circumstances
  - Fix typo in build script in detection of SQLite3
  - Fix character set conversion in desktop notification code
  - Merged upstream PuTTY changes for compatibility with PuTTY 0.61
  - Updated built-in TinyXML
    3.5.0 (2011-05-22)
  - Don't create queue.xml anymore if it does not exist
  - Several fixes to build system and environment
    3.5.0-rc2 (2011-05-15)
    + Added experimental setting to strip file revision upon download from VMS servers. Set "Strip VMS revisions" to 1 in FileZilla.xml to enable
  - The string coalescer benchmark debug option no longer crashes if benchmarking an empty string coalescer
    3.5.0-rc1 (2011-05-08)
    + The transfer queue is now stored in an SQLite database.
  - Fixed crash during shutdown of FileZilla
  - Clearing the queue when it was not yet fully populated no longer causes a crash
  - If using ask login type for a site and no username is given, the initial focus is now on the user box in the login dialog
* Fri Apr 29 2011 pth@novell.com
- Update to 3.4.0. Changes since 3.3.4.1:
    3.3.5-rc1 (2010-11-07)
    + FTP over TLS certificate store is now host-specific
    + MSW: Large-DPI awareness
    + Improved SFTP transfer speeds
    + FTP over TLS should prefer ciphers with longer key sizes
    + Add context menu entry to re-queue all files on the successful and
    failed queue tabs
  - Resuming of uploads was not working correctly in all cases
  - Correct remaining time calculation in queue
  - Do not show welcome dialog in kiosk mode 2
  - Do not offer option to permanently accept certificate in kiosk mode 2
  - Fix sorting by size in filelists with directory sort behavior set to
    inline
  - Directly save settings after importing from file
    3.3.5.1 (2010-11-21)
  - Permanently trusting certificates had no effect until FileZilla was
    restarted
  - Fix downloading of symbolic links to files
    3.4.0-beta1 (2011-01-09)
    + Added option to force use of insecure plain FTP to Site Manager
    + Kiosk mode option can now also be read from FileZilla.xml, with
    fzdefaults.xml having priority if setting exists in both files
  - Fix memory leak in directory cache
  - Compatibility with obscure DOS servers using forward slashes as path
    delimiter
  - Improve text wrapping engine
    3.4.0-rc1 (2011-03-20)
    + Add checkbox to settings dialog to not save passwords
    + Add timestamp columns to successful and failed queue tabs showing
    when the transfers completed or failed
  - Fixed infinite loop in TinyXML when loading settings from corrupt
    XML documents
  - Parsing MDTM reply now takes seconds into account
  - Compatibility with MVS listing containing PO-E type entries
  - Fix Resizing issues with manual transfers dialog
* Tue Apr  5 2011 pth@suse.de
- Fix typo in putty-no_DATE_and_TIME_.patch.
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets-wxcontainer, it does not compile with STL
  variant.
- Fixed invalid translation locales (filezilla#6514).
- Fixed project URL.
* Fri Nov  5 2010 pth@suse.de
- Update to 3.3.4.1:
  * Set a minimum size for column widths in directory lists and
    transfer queue.
  * Fix build-time check for system TinyXML.
  * Update german translation.
- Fix Provides and Obsoletes.
- Don't use __DATE__ and __TIME__ in included Putty source
  in order to reduce package rebuilds.
* Wed Mar 31 2010 pth@novell.com
- Use %%lang_package macro.
* Fri Mar 26 2010 pth@novell.com
- Refresh german message catalog and disambiguate messages
  marked fuzzy.
- Split off message catalogs into a -lang subpackage.
* Tue Mar 23 2010 per@osbeck.com
- update to v3.3.2.1
  - Remember location of update download directory
  - Cancel file renaming on actions that change the file list, such as changing sort order or performing a refresh
  - Cancel file renaming if starting a drag&drop operation
  - Filter invalid characters if downloading through double-clicking files or if adding from the search dialog
  - Fix site-specific bookmarks menu
  - The menu did not reflect initial value of preserve timestamp option properly
  - MSW: Keep FileZilla subdirectory in startmenu when updating, preserves custom order
  - MSW: Add AppID support to installer
* Tue Mar 16 2010 per@osbeck.com
- update to v3.3.2
- *nix: Add support for forward and backward mouse buttons
- Speed limits can be re-enabled on SFTP connections
- Changed settings did not come into effect unless FileZilla was restarted
- Small performance improvements
- Spelling fixes
- Rebuilt due to timer problems
- Speed limits can be quickly set using the menu and a new indicator in the status bar
- Display number of bytes transferred and duration of transfer in log
- MSW: React to back button of mouse in file lists
- Updated blukis icon set
- Refactored large parts of the toolbar and menubar code
- A race condition in the socket code could lead to crashes
- Fix connecting to addresses longer than 15 characters if using SOCKS proxy
- Get add to queue in local directory tree context menu working again
- Do not open request dialogs if user is holding a mouse button
- Forward all Ctrl+Tab key events to tab bar
- Do not report SFTP exitcodes that do not originate from the server
* Tue Feb 16 2010 seife@opensuse.org
- update to v3.3.1, to fix the build problems with newer libgnutls
* Thu Nov 22 2007 pth@suse.de
- Package renamed from FileZilla to filezilla because only the tarball
  is named with mixed case.
- Provide a filezilla-rpmlintrc
- Update to 3.0.3. Changes since 3.0.0.beta6:
  - Install some default filters if filters.xml missing in user's settings
    directory
  - Additional fixes for SFTP servers with nonstandard filename encodings
  - Automatic server timezone detection. Custom offset in the Site Manager
    may need to be adjusted. FTP only.
  - Option to preserve file timestamps on downloads (all protocols)
  - Option to preserve file timestamps on uploads on FTP servers supporting
    the MFMT command
  - Add transfer type (ascii/binary/auto) selection to transfer menu
  - Shorten very long filenames on file exists dialog
  - Attempt at working around broken routers and firewalls disconnecting
    the control connection of the transfer session on transfers
  - Deleting directories containing lots of files should be faster now
  - Disallow settings/site import from files located in the settings storage
    directory
  - Fix nullpointer dereference on non-UTF8 enabled SFTP servers
  - Fix button height inconsistencies on dialogs with certain artwork
    (e.g. Ubuntu 7.10)
  - Fix issue with message log not working properly
  - Experimental support for z/VM servers
  - Fix typo in option handling code. Due to this, settings for date/time
    formatting have been reset.
  - Fix performance problem if FileZilla gets started with message log
    hidden
  - Work around possible race conditions in SFTP input thread leading to
    crashes
  - Remote file viewing / editing
  - Display current server in window title
  - Don't remember incorrect password on SFTP connections with ASK
    logontype
  - Fix Makefiles so SFTP properly supports files > 2GB
  - Ascii filetype setting for extensionless files and dotfiles had
    negated effect
  - Fix error message if using multiple running instances save the
    settings at the same time
  - Fix parsing of very new files in directory listings if server is in a
    timezone ahead of the client
  - Fix range of timezone offset setting
  - Fix problems with remote path combobox if reconnecting after a
    disconnect
  - Display confirmation dialog if deleting file from remote directory
    tree context menu
  - Refresh remote directory listing after refreshing a single file
  - On very first startup, center FileZilla on screen
  - Fix parsing of settings or site XML data containing double, leading or
    trailing whitespace.
  - Settings to configure size, date and time formatting
  - Message log and queue visibility will be remembered
  - Custom action to perform after queue completion
  - Add some confirmation dialogs
  - Fix misplaced settings dialog
  - Fix problems with remembering pane size
  - Properly refresh local directory if downloading into newly created
    subdirectories
  - Fix issues with language set to Japanese
  - New application icon
  - Fix support for servers sending directory listing in yet another
    exotic format
  - Fix prefix search in list controls on wxGTK
  - Work around problem with wxSpinCtrl in site manager on wxGTK
  - Fix assertion on wxGTK if listing extensionless files
  - Fix buffer overflow if directory lisiting filters were enabled,
    causing FileZilla to crash.
  - Backspace key can be used to goes to parent directory in file lists
  - Fix file selection by entering filename prefix
  - Restore correct window size if FileZilla gets closed while minimized
  - Disable "Create directory" entry in remote filelist context menu
    while disconnected
  - Improve compatibility with SFTP servers using exotic listing formats
  - Fix queue scrolling
  - Remember Window size and position
  - Remember sort column and order of file lists
  - Additional icon set by Brian Lukis
  - Added .desktop file on *nix systems
  - If server is crippled and doesn't allow more than one connection
    (based on Sitemanager preference), primary browsing connection can be
    used by the transfer queue
  - Fix SSL transfers hanging if using speed limits
  - Compile fixes and compatibility improvements for various platforms
  - The usual assortment of small bugfixes, see changelog for details
  - Fix remotely triggered memory corruption if connection gets terminated
    during TLS handshake.
  - Column withs in all list views will be saved
  - Refresh local file list after a successful file transfer
  - Add context menu to remote directory tree
  - Make Site Manager resizable
  - Don't leave empty files behind on failed downloads
  - Fix retry and cache logic if transfer command fails with 5yz reply
  - Limit number of simultaneous connections did not work properly
  - Refresh listing after chmod
  - Fix upload of empty files over TLS connections
  - Improved queue
  - Import and export dialogs including import of Sitemanager data
    from legacy FZ 2.x
  - Tab key can be used to switch between panes
  - F6 toggles between quickconnect bar and local/remote path edit fields
  - Location of settings directory can be specified in fzdefaults.xml
  - Engine state could get mixed up if transfers failed
  - Transfer of empty files could incorrectly time out
  - Fix directory cache coherency if removing/renaming directories
  - Work around lack of thread-safety in wxWidgets causing random
    misbehaviour
  - Properly disconnect idle transfer engines after 30 seconds
  - Update selections if changing sort order of file lists
  - Various minor fixes
  - Add "View hidden files" option to server menu
  - Add dialog to clear private data
  - Performance improvements of message log
  - Avoid sending unnecessary TYPE commands
  - Updated TinyXML component, fixes problems with filenames
    containing ampersands or other special XML entities.
  - Don't retry connecting if user cancels new/changed hostkey
    notification
  - Fix data corruption on FTPS uploads
  - Implement speed limits
  - Last used local directory will be remembered
  - New option for the sorting of the filelists. Directories can be kept
    on top or sorted inline.
  - Display warning if detecting a Windows system with a networking bug
    confirmed by Microsoft
  - Right-clicking the Sitemanager button in the toolbar displays a popup
    menu with the sites for quick access. On Windows, a dropdown arrow got
    added.
  - Autocompletion did not work properly on GTK based systems
  - Uninstalling FileZilla on Windows should no longer leave registry keys
    behind
  - lots of small bugfixes
  - New optionspage to change layout of file and directory panes
  - Loading of predefined Sitemanager entries from fzdefaults.xml
  - UTF-8 support for SFTP, merged in upstream changes from PuTTY.
  - Ascii file FTP transfers should now work properly on non-Windows
    systems
  - Fix SFTP transfers of filenames containing the following
    characters: [ ] \ * ?
  - lots of small bugfixes and performance improvements
* Wed May 16 2007 pth@suse.de
- Fix comparison of pointer with string.
* Fri May  4 2007 pth@suse.de
- Initial package
